##
##  imapd.spec -- OpenPKG RPM Specification
##  Copyright (c) 2000-2003 Cable & Wireless Deutschland GmbH
##  Copyright (c) 2000-2003 The OpenPKG Project <http://www.openpkg.org/>
##  Copyright (c) 2000-2003 Ralf S. Engelschall <rse@engelschall.com>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         imapd
Summary:      Cyrus IMAP Server
URL:          http://asg.web.cmu.edu/cyrus/imapd/
Vendor:       Carnegie Mellon University
Packager:     The OpenPKG Project
Distribution: OpenPKG [PLUS]
Group:        Mail
License:      BSD
Version:      2.1.14
Release:      20030707_kolab

#   package options
%option       with_fsl         yes
%option       with_vhost_hack  no
%option       with_groupfile_hack no

#   list of sources
Source0:      ftp://ftp.andrew.cmu.edu/pub/cyrus-mail/cyrus-imapd-%{version}.tar.gz
Source1:      rc.imapd
Source2:      cyrus.conf
Source3:      imapd.conf
Source4:      fsl.imapd
Patch0:       imapd.patch
Patch1:       vhosthack.patch
Patch2:       groupfile.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20030415, perl, perl-openpkg, make
PreReq:       OpenPKG, openpkg >= 20030415, perl, MTA
BuildPreReq:  sasl, db >= 4.1.24, openssl
PreReq:       sasl, db >= 4.1.24, openssl
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif
AutoReq:      no
AutoReqProv:  no
Provides:     IMAP

%description
    The Cyrus IMAP server is an IMAP4 and POP3 daemon that differs from
    other IMAP server implementations in that it is generally intended to
    be run on sealed servers, where normal users are not permitted to log
    in. The mailbox database is stored in parts of the filesystem that are
    private to the Cyrus IMAP system. All user access to mail is through
    the IMAP, POP3, or KPOP protocols.

%prep
    %setup -q -n cyrus-imapd-%{version}
%if "%{with_groupfile_hack}" == "yes"
    %patch2 -p0
%endif
    %{l_shtool} subst \
        -e 's;db-4.1;db;g' \
        configure

    #   ensure linking of Berkeley DB
    %{l_shtool} subst \
        -e 's;^\( *.LIBS..*\)\(\"\],.*\)$;\1 -ldb\2;' \
        perl/imap/Makefile.PL

    #   ensure invocation of correct perl in cyradm
    %{l_shtool} subst \
        -e 's;^\(.) exec\) \(perl .*\)$;\1 %{l_prefix}/bin/\2;' \
        perl/imap/cyradm.sh

    #   adjust hard-coded location of sieve
    %{l_shtool} subst \
        -e 's;"/usr/sieve";"%{l_prefix}/var/imapd/sieve";g' \
        imap/lmtpd.c \
        imap/mbdump.c \
        imap/user.c \
        man/imapd.conf.5 \
        timsieved/actions.c

    #   adjust default config to install environment for use in mkimap install helper script
    %{l_shtool} install -c -m 644 \
        -e "s;@l_prefix@;$RPM_BUILD_ROOT%{l_prefix};g" \
        -e "s;@l_rusr@;%{l_rusr};g" \
        %{SOURCE imapd.conf} \
        imapd.conf-mkimap
    %{l_shtool} subst \
        -e 's;^exec perl ;exec %{l_prefix}/bin/perl ;' \
        -e "s;/etc/imapd.conf;%{l_prefix}/etc/imapd/imapd.conf;" \
        -e "s;^\(\$sievedir = \).*$;\1 shift || \"%{l_prefix}/var/imapd/sieve\"\;;" \
        tools/mkimap

    #   ajdust syslog ident of deliver program
    %{l_shtool} subst \
        -e '/config_init/s;"deliver";"cyrdeliver";' \
        imap/deliver.c

%if "%{with_vhost_hack}" == "yes"
    #   allow @ in LMTP mailbox names
    %{l_patch} -p1 <%{SOURCE vhosthack.patch}
%endif

%build
    cflags="%{l_cppflags}"
    ldflags="%{l_ldflags} %{l_fsl_ldflags}"
    case "%{l_target}" in
        *-solaris* ) ldflags="$ldflags -lsocket -lnsl" ;;
    esac
    CC="%{l_cc}" \
    CPPFLAGS="$cflags" \
    CFLAGS="%{l_cflags -O} $cflags" \
    LDFLAGS="$ldflags" \
    LIBS="%{l_fsl_libs}" \
    ./configure \
        --cache-file=./cache.config \
        --prefix=%{l_prefix} \
        --with-openssl=%{l_prefix} \
        --with-dbdir=%{l_prefix} \
        --with-sasl=%{l_prefix} \
        --with-statedir=%{l_prefix}/var/imapd \
        --with-auth=unix \
        --without-libwrap \
        --without-perl \
        --without-ucdsnmp \
        --with-cyrus-prefix=%{l_prefix} \
        --with-cyrus-user=%{l_rusr} \
        --with-cyrus-group=%{l_rgrp}

    #   redirect the hard-coded file paths
    %{l_shtool} subst \
        -e 's;/etc/\(.*\).conf;%{l_prefix}/etc/imapd/\1.conf;' \
        imap/*.c imap/*.h master/*.c master/*.h
    %{l_shtool} subst \
        -e 's;/etc/mail/cyrusmap\.db;%{l_prefix}/var/imapd/cyrusmap.db;' \
        imap/sendmail-map.c
    %if "%{with_groupfile_hack}" == "yes"
      %{l_shtool} subst -e "s;/etc/imapd.group;%{l_prefix}/halole/etc/imapd/imapd.group;" \
         lib/auth_unix.c
    %endif

    %{l_make} %{l_mflags}

%install
    #   build (and install) Perl-based administration stuff
    %{l_prefix}/bin/perl-openpkg prolog
    export SASL_INC="%{l_cppflags}"
    export SASL_LIB="%{l_ldflags} -lsasl2"
    export OPENSSL_INC="%{l_cppflags}"
    export OPENSSL_LIB="%{l_ldflags} -lssl -lcrypto"

    %{l_prefix}/bin/perl-openpkg install -d perl/imap
    ( cd perl/sieve
      #   FIXME: private information from perl-openpkg
      tag="${RPM_PACKAGE_NAME}-${RPM_PACKAGE_VERSION}-${RPM_PACKAGE_RELEASE}"
      perl="${RPM_BUILD_DIR}/perl-$tag"
      %{l_make} PERL="$perl"
    ) || exit 1
    %{l_prefix}/bin/perl-openpkg install -d perl/sieve/managesieve
    %{l_prefix}/bin/perl-openpkg install -d perl/sieve/acap
    %{l_prefix}/bin/perl-openpkg epilog

    %{l_make} %{l_mflags} install \
        prefix=$RPM_BUILD_ROOT%{l_prefix} \
        exec_prefix=$RPM_BUILD_ROOT%{l_prefix} \
        cyrus_prefix=$RPM_BUILD_ROOT%{l_prefix}
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/imapd \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/var/imapd/spool \
        $RPM_BUILD_ROOT%{l_prefix}/bin
    %{l_shtool} install -c -m 755 \
        perl/sieve/scripts/sieveshell.pl \
        $RPM_BUILD_ROOT%{l_prefix}/bin/sieveshell

    ( cd perl/imap && %{l_prefix}/bin/perl-openpkg install )
    ( cd perl/sieve/managesieve && %{l_prefix}/bin/perl-openpkg install )
    ( cd perl/sieve/acap && %{l_prefix}/bin/perl-openpkg install )

    #   install sieve adminstration script
    %{l_shtool} install -c -m 755 \
        perl/sieve/scripts/sieveshell.pl \
        $RPM_BUILD_ROOT%{l_prefix}/bin/sieveshell

    #   offer a sane configuration

    l_hostname=`%{l_shtool} echo -e %h`
    l_domainname=`%{l_shtool} echo -e %d | cut -c2-`
    %{l_shtool} install -c -m 644 \
        -e 's;@l_prefix@;%{l_prefix};g' \
        -e 's;@l_rusr@;%{l_rusr};g' \
        -e "s;@l_hostname@;$l_hostname;g" \
        -e "s;@l_domainname@;$l_domainname;g" \
        %{SOURCE cyrus.conf} \
        %{SOURCE imapd.conf} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/imapd/

    #   install the run command file
    %{l_shtool} install -c -m 755 \
        -e 's;@l_prefix@;%{l_prefix};g' \
        -e 's;@l_susr@;%{l_susr};g' \
        -e 's;@l_rusr@;%{l_rusr};g' \
        -e 's;@l_rgrp@;%{l_rgrp};g' \
        %{SOURCE rc.imapd} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   use mkimap to create many directories for us
    tools/mkimap imapd.conf-mkimap $RPM_BUILD_ROOT%{l_prefix}/var/imapd/sieve

    #   rename files which are likely to cause namespace conflicts
    ( cd $RPM_BUILD_ROOT%{l_prefix}
      for i in deliver master quota reconstruct; do
          mv bin/$i        bin/cyr$i
          mv man/man8/$i.8 man/man8/cyr$i.8
      done )

    #   install from tools
    %{l_shtool} install -c -m 755 \
        tools/mkimap \
        $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   install OSSP fsl configuration
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/etc/fsl
    %{l_shtool} install -c -m 644 \
        -e 's;@l_prefix@;%{l_prefix};g' \
        %{SOURCE fsl.imapd} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   strip binaries
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true

    #   determine files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%not %dir %{l_prefix}/etc/fsl' \
        '%config %{l_prefix}/etc/fsl/fsl.imapd' \
        '%config %{l_prefix}/etc/imapd/imapd.conf' \
        '%config %{l_prefix}/etc/imapd/cyrus.conf' \
        '%dir %attr(0750,%{l_rusr},%{l_mgrp}) %{l_prefix}/var/imapd' \
        '%dir %attr(0750,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/imapd/*' \
        '%dir %attr(0770,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/imapd/*/*' \
        '%dir %attr(0770,%{l_musr},%{l_rgrp}) %{l_prefix}/var/imapd/socket'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

